@@ -29,6 +29,17 @@ def get_or_create_from_small_resource(resource):
     '''
     Return instance of right type based on dictionary resource from Facebook API Graph
     '''
+    try:
+        return Page.objects.get(graph_id=resource['id'])
+    except Page.DoesNotExist:
+        try:
+            return User.objects.get(graph_id=resource['id'])
+        except User.DoesNotExist:
+            try:
+                return Application.objects.get(graph_id=resource['id'])
+            except Application.DoesNotExist:
+                pass
+
     keys = sorted(resource.keys())
     defaults = dict(resource)
     del defaults['id']
@@ -55,15 +66,15 @@ class PostFacebookGraphManager(FacebookGraphManager):
 
     @atomic
     @fetch_all(return_all=update_count_and_get_posts, always_all=True, paging_next_arg_name='until')
-    def fetch_page_wall(self, page, limit=250, offset=0, until=None, since=None, **kwargs):
+    def fetch_page_wall(self, page, limit=250, offset=0, until=None, since=None, edge='posts', **kwargs):
         '''
         Arguments:
          * until|since - timestamp or datetime
         '''
-        kwargs = {
+        kwargs.update({
             'limit': int(limit),
             'offset': int(offset),
-        }
+        })
         for field in ['until', 'since']:
             value = locals()[field]
             if isinstance(value, datetime):
@@ -74,7 +85,7 @@ class PostFacebookGraphManager(FacebookGraphManager):
                 except TypeError:
                     raise ValueError('Wrong type of argument %s: %s' % (field, type(value)))
 
-        response = graph('%s/posts' % page.graph_id, **kwargs)
+        response = graph('%s/%s' % (page.graph_id, edge), **kwargs)
         ids = []
         if response:
             log.debug('response objects count - %s' % len(response.data))
@@ -213,13 +224,14 @@ class Post(FacebookGraphIDModel, FacebookLikableModel):
             self.author = get_or_create_from_small_resource(self.author_json)
 
         if self.owners.count() == 0 and self.owners_json:
+            self._external_links_to_add['owners'] = []
             for owner_json in self.owners_json:
                 try:
                     owner = get_or_create_from_small_resource(owner_json)
                 except UnknownResourceType:
                     continue
                 if owner:
-                    self._external_links_to_add += [('owners', PostOwner(post=self, owner=owner))]
+                    self._external_links_to_add['owners'] += [PostOwner(post=self, owner=owner)]
 
     def update_count_and_get_comments(self, instances, *args, **kwargs):
         self.comments_count = instances.count()
@@ -390,8 +402,12 @@ class Comment(FacebookGraphIDModel, FacebookLikableModel):
         if 'like_count' in response:
             response['likes_count'] = response.pop('like_count')
 
-        # transform graph_id from {POST_ID}_{COMMENT_ID} -> {PAGE_ID}_{POST_ID}_{COMMENT_ID}
-        if response['id'].count('_') == 1:
+        # transform graph_id from -> {PAGE_ID}_{POST_ID}_{COMMENT_ID}
+        if response['id'].count('_') == 0:
+            # group posts comments {COMMENT_ID} -> {PAGE_ID}_{POST_ID}_{COMMENT_ID}
+            response['id'] = '_'.join([self.post.graph_id, response['id']])
+        elif response['id'].count('_') == 1:
+            # page posts comments {POST_ID}_{COMMENT_ID} -> {PAGE_ID}_{POST_ID}_{COMMENT_ID}
             response['id'] = re.sub(r'^\d+', self.post.graph_id, response['id'])
 
         super(Comment, self).parse(response)
@@ -405,4 +421,4 @@ class Comment(FacebookGraphIDModel, FacebookLikableModel):
         except:
             owner_screenname = ''
         post_id, comment_id = self.graph_id.split('_')[1:]
-        return super(Comment, self).get_url('%s/posts/%s?comment_id=%s' % (owner_screenname, post_id, comment_id))
\ No newline at end of file
+        return super(Comment, self).get_url('%s/posts/%s?comment_id=%s' % (owner_screenname, post_id, comment_id))
