@@ -13,6 +13,7 @@ POST2_ID = '100001341687090_632170373504346'
 COMMENT1_ID = '19292868552_10150475844632302_20258978'
 
 PAGE1_ID = '1411299469098495'
+GROUP_CLOSED_ID = '167276666692692'
 
 POST_WITH_MANY_LIKES_ID = '19292868552_10151516882688553'
 POST_WITH_MANY_COMMENTS_ID = '19292868552_10150475844632302'
@@ -204,6 +205,16 @@ class FacebookPostsTest(TestCase):
         self.assertTrue(posts_count1 < posts_count)
         self.assertEqual(posts_count1, len(posts))
 
+#     def test_group_closed_fetch_posts(self):
+#
+#         page = PageFactory(graph_id=GROUP_CLOSED_ID)
+#
+#         self.assertEqual(Post.objects.count(), 0)
+#
+#         posts = page.fetch_posts(all=True)
+#
+#         self.assertTrue(len(posts) > 0) # ensure user has access to closed group
+
     def test_page_fetch_many_posts(self):
 
         page = PageFactory(graph_id=PAGE1_ID)
@@ -216,4 +227,4 @@ class FacebookPostsTest(TestCase):
 
         self.assertTrue(posts_count > 250)
         self.assertEqual(posts_count, len(posts))
-        self.assertTrue(posts.filter(created_time__lte=datetime(2014, 1, 7)).count(), 1)
\ No newline at end of file
+        self.assertTrue(posts.filter(created_time__lte=datetime(2014, 1, 7)).count(), 1)
